function chamberSeparatorCluster(info)

% Remarks:
% - Cropping method change on 20101211

expDirectory = info.expDirectory;
expName = info.expName;
inputDir = info.rawImageDir;
outputDir = info.rotatedDir;
p = info.position;
Nstart = info.Nstart;
Nend = info.Nend;
showFigure = info.chamberSeparator.showFigure;
templateFile = info.chamberSeparator.templateFile;
fluoCorrFile = info.chamberSeparator.fluoCorrFile;


% Options
warning off;

% Parameters
maxRotation = 6;
cropping = 30;
tridentFactor = 1.5;
x_window = 50;

initShift.left = -300;
initShift.right = 300;
initShift.up = -300; 
initShift.down = 300;
newShift.left = -20; 
newShift.right = 20; 
newShift.up = -20; 
newShift.down = 20;
totalShift.left = -300;
totalShift.right = 300;
totalShift.up = -300; 
totalShift.down = 300;

chamberOffset = info.chamberSeparator.chamberOffset;

% Alignment template
template = imread(templateFile);
threshold = graythresh(template);
BWtemplate = im2bw(template,threshold);
%figure, imshow(BWtemplate);

% Path info
mainWorkingDirectory = fullfile(pwd,'workingDir');

% Saving directories
alignmentDataDir = fullfile(mainWorkingDirectory,'alignmentData');
mkdir(alignmentDataDir);
imageAlignmentDir = fullfile(mainWorkingDirectory,'imageAlignment');
mkdir(imageAlignmentDir);
rotatedImageDir = fullfile(expDirectory,outputDir);
mkdir(rotatedImageDir);


%% Run

% Processing image stack

fileFolder = fullfile(expDirectory,inputDir,sprintf('pos%d',p));
dirOutputDia = dir(fullfile(fileFolder,'dia',sprintf('*_dia_pos%d_*',p)));
fileNameDia = {dirOutputDia.name}';
%Nimage = length(fileNameDia);
alignment = [];
nSet = Nstart:Nend;
Fcount = 0;
for n=nSet
    
    Fcount = Fcount + 1;
    timeString = regexp(fileNameDia{n},'_t(\d+)_(\d+).tif','tokens');
    date = timeString{1}{1};
    writeTime = timeString{1}{2};
    time = sscanf(writeTime,'%2f %2f %2f');
        
    % Save frame info
    alignment.exp = expDirectory;
    alignment.pos = p;
    alignment.frame{Fcount} = n;
    alignment.date{Fcount} = date;
    alignment.time{Fcount} = writeTime;
    alignment.hours{Fcount} = time(1);
    alignment.minutes{Fcount} = time(2);
    alignment.seconds{Fcount} = time(3);
    
    % Load dia image
    I = imread(fullfile(fileFolder,'dia',fileNameDia{n}));
    %figure, imshow(imadjust(I));

    % Get rotation
    [rotation, BW] = lineFinder(I,maxRotation);
    rot(Fcount) = rotation;
    BWkeep{Fcount} = BW;
    
    % Fluorescence image correction
    if ~strcmpi(fluoCorrFile,'')
        if Fcount == 1 %Get fluorescence correction image
            F = imread(fluoCorrFile); %figure, imshow(imadjust(F));
            F = double(F); %figure, imshow(imadjust(F));
            F = F./mean(F(:)); %figure, imshow(imadjust(F));
        end
%         figure(1), clf,
%         subplot(1,2,1), imshow(imadjust(epiImage));
%         subplot(1,2,2), imshow(imadjust(E{n}));
%     else
%         epiImage = imread(fullfile(fileFolder,'epi',fileNameEpi{n}));
%         E{n} = epiImage;
    end
end

rotation = mean(rot);
cropSize = ceil(size(BW,1)*sin((pi/180)*abs(rotation)))+1;

Fcount = 0;
for n=nSet

    Fcount = Fcount + 1;
    
    %figure, imshow(imadjust(epiImage));

    % Load dia image
    I = imread(fullfile(fileFolder,'dia',fileNameDia{n}));
    %figure, imshow(imadjust(I));
    
    % Load BW image
    BW = BWkeep{Fcount};
    
    % Restrict image to image shift
    if Fcount == 1    
        maxShift = initShift;
    else
        maxShift.left = imageAlignment.x_shift + newShift.left;
        maxShift.right = imageAlignment.x_shift + newShift.right;  
        maxShift.up = imageAlignment.y_shift + newShift.up;
        maxShift.down = imageAlignment.y_shift + newShift.down;
        if maxShift.left < totalShift.left || maxShift.right > totalShift.right || maxShift.up < totalShift.up || maxShift.down > totalShift.down
            maxShift = initShift;
        end
    end
    
    % Rotate image
    BWrotated = imcrop(imrotate(BW,-rotation),[1+cropSize 1+cropSize size(BW,2)-cropSize size(BW,1)-cropSize]);
    Irotated = imcrop(imrotate(I,-rotation),[1+cropSize 1+cropSize size(I,2)-cropSize size(I,1)-cropSize]);
    
    M = size(BWrotated,1)-size(BWtemplate,1);
    N = size(BWrotated,2)-size(BWtemplate,2);
    BWtemp = BWtemplate;
    if M < 0; BWtemp=BWtemplate(ceil(-M/2)+1:end-floor(-M/2)-1,:); end
    if N < 0; BWtemp=BWtemplate(:,ceil(-N/2)+1:end-floor(-N/2)-1); end
    
    % Image alignment
    imageAlignment = shiftImage(BWrotated,BWtemp,rotation,maxShift,x_window,tridentFactor);
    alignment.imageAlignment{Fcount} = imageAlignment;
    
end

% Find continuous shift
t = 0:Fcount-1;
for k=1:Fcount
    xShift(k) = alignment.imageAlignment{k}.x_shift;
    yShift(k) = alignment.imageAlignment{k}.y_shift;
end
xCof = polyfit(t,xShift,2);
xShiftFit = xCof(1)*t.^2+xCof(2)*t+xCof(3);
yCof = polyfit(t,yShift,2);
yShiftFit = yCof(1)*t.^2+yCof(2)*t+yCof(3);
for k=1:Fcount
    alignment.imageAlignment{k}.x_shift = round(xShiftFit(k));
    alignment.imageAlignment{k}.y_shift = round(yShiftFit(k));
end
[xShiftMinL, idxMinL] = min(round(xShiftFit));
[xShiftMinR, idxMinR] = max(round(xShiftFit));
[yShiftMinD, idxMinD] = min(round(yShiftFit));

if showFigure == 1; 
    figure(10), clf, hold on;
        color=jet(Fcount);
        for k=1:Fcount
            plot(xShift(k),yShift(k),'-+','Color',color(k,:));
        end
        plot(xShift,yShift,'-k');
    figure(11), clf;
        subplot(1,2,1), plot(xShift);
        subplot(1,2,2), plot(yShift);
    figure(12), clf;
        subplot(1,2,1), hold on, plot(t,xShift,' +r'), plot(t,xShiftFit,'b'); 
        subplot(1,2,2), hold on, plot(t,yShift,' +r'), plot(t,yShiftFit,'b'); 
end

% Crop and save images
Fcount = 0;
for n=nSet
    
    Fcount = Fcount + 1;
    
    % Load epi image
    %figure, imshow(imadjust(epiImage));

    % Load dia image
    I = imread(fullfile(fileFolder,'dia',fileNameDia{n}));
    %figure, imshow(imadjust(I));
    
    % Load BW image
    BW = BWkeep{Fcount};

    % Rotate image
    BWrotated = imcrop(imrotate(BW,-rotation),[1+cropSize 1+cropSize size(BW,2)-cropSize size(BW,1)-cropSize]);
    Irotated = imcrop(imrotate(I,-rotation),[1+cropSize 1+cropSize size(I,2)-cropSize size(I,1)-cropSize])
    
    imageAlignment = getROIs_IA(Irotated,Irotated,alignment.imageAlignment{Fcount},chamberOffset,showFigure);
    
    % Save aligment image and data
    imageShow = imageAlignementShow(Irotated,BWrotated,BWtemp, imageAlignment);
    if showFigure == 1; figure(2), imshow(imageShow); end
    imwrite(imageShow,fullfile(imageAlignmentDir,sprintf('fittedAlignment_%s_pos%d_frame0%d.jpg',expName,p,n)),'Quality',50);
    
    x_center = alignment.imageAlignment{Fcount}.x_center;
    y_center = alignment.imageAlignment{Fcount}.y_center;
    
    [Ni,Mi] = size(Irotated);
    w1Min = x_center+xShiftMinL+chamberOffset.xL;
    w2Min = Mi-(x_center+xShiftMinR+chamberOffset.xR);
    h1Min = y_center+yShiftMinD+chamberOffset.yL;
    h2Min = y_center+yShiftMinD+chamberOffset.yR;
    
    h1 = imageAlignment.ROI{1}.h;
    w1 = imageAlignment.ROI{1}.w;
    x2 = imageAlignment.ROI{2}.x;
    y2 = imageAlignment.ROI{2}.y; 
    h2 = imageAlignment.ROI{2}.h;
    w2 = imageAlignment.ROI{2}.w;
    leftDiaCrop = imcrop(Irotated,[w1-w1Min+1 h1-h1Min+1 w1Min h1Min]);
    rightDiaCrop = imcrop(Irotated,[x2 h2-h2Min+1 w2Min h2Min]);

    mkdir(rotatedImageDir,sprintf('pos%d_L',p));
    mkdir(fullfile(rotatedImageDir,sprintf('pos%d_L',p),'dia'));
    imwrite(leftDiaCrop,fullfile(rotatedImageDir,sprintf('pos%d_L',p),'dia',sprintf('left_dia_pos%d_t%s_%s.tif',p,alignment.date{Fcount},alignment.time{Fcount})));

    mkdir(rotatedImageDir,sprintf('pos%d_R',p));
    mkdir(fullfile(rotatedImageDir,sprintf('pos%d_R',p),'dia'));
    imwrite(rightDiaCrop,fullfile(rotatedImageDir,sprintf('pos%d_R',p),'dia',sprintf('right_dia_pos%d_t%s_%s.tif',p,alignment.date{Fcount},alignment.time{Fcount})));

    alignment.imageAlignment{Fcount} = imageAlignment;
                 
end

save(fullfile(alignmentDataDir,sprintf('alignmentData_%s_pos%d.mat',expName,p)),'alignment');

end
