function [rotation, BW] = lineFinder(I,maxRotation)


% morphological operators
d50 = strel('disk',50);
d30 = strel('disk',30);
d10 = strel('disk',10);
s50 = strel('rectangle', [50 50]);
s30 = strel('rectangle', [30 30]);
r40_10 =strel('rectangle', [40 10]);
r60_10 =strel('rectangle', [60 10]);
l20_v = strel('line',20,0);
l20_h= strel('line',20,90);
l10_v = strel('line',10,0);
l10_h = strel('line',10,90);
l5_v = strel('line',5,0);
l5_h = strel('line',5,90);
c21 = zeros(21);
c21(11,:) = 1; c21(:,11) = 1;
cross21 = strel('arbitrary',c21);

           
%Image processing
[BWedge, thres] = edge(I);
BWclose1 = imclose(BWedge,d30);
BWclose2 = imclose(BWclose1,r60_10);
BWedge2 = edge(BWclose2);
BWedge3 = imdilate(BWedge2,l5_v);
BWedge4 = imdilate(BWedge3,l5_h);
BW = BWedge4;
%figure, imshow(BW), title('Analyzed image - contour');


% Hough transform
[H,theta,rho] = hough(BW,'ThetaResolution',0.2);
% figure, imshow(imadjust(mat2gray(H)),[],'XData',theta,'YData',rho,...
%        'InitialMagnification','fit'), title('Analyzed image - Hough transform');
% xlabel('\theta (degrees)'), ylabel('\rho');
% axis on, axis normal, hold on;
% colormap(hot)

P = houghpeaks(H,5,'threshold',ceil(0.3*max(H(:))));
x = theta(P(:,2));
y = rho(P(:,1));
%plot(x,y,'s','color','c');

lines = houghlines(BW,theta,rho,P,'FillGap',5,'MinLength',7);

if isfield(lines,'point1')

    %figure, imshow(BW), title('Anaylzed imaged - lines'), hold on;
    best_len = 0;
    k_best = 0;
    L = length(lines);
    len = zeros(1,L);

    for k = 1:L
       xy = [lines(k).point1; lines(k).point2];
       %plot(xy(:,1),xy(:,2),'LineWidth',2,'Color','green');
       %plot(xy(1,1),xy(1,2),'x','LineWidth',2,'Color','yellow');
       %plot(xy(2,1),xy(2,2),'x','LineWidth',2,'Color','red');
       len(k) = norm(lines(k).point1 - lines(k).point2);
       vertical = (lines(k).theta > - maxRotation) && (lines(k).theta < maxRotation);
       if (len(k) > best_len) && vertical
          best_len = len(k);
          best_angle = lines(k).theta;
          k_best = k;
          xy_long = xy;
       end
    end
    %plot(xy_long(:,1),xy_long(:,2),'LineWidth',2,'Color','cyan');

    if k_best == 0
        rotation = 0;
    else
        rotation = -lines(k_best).theta;
    end

else
    
rotation = 0;    

end

