function [names, values] = nd_hullfeatures(imageproc,mask)
% MB_HULLFEATURES - calculates features using the convex hull of IMAGE
% [NAMES, VALUES] = MB_HULLFEATURES(IMAGEPROC, IMAGEHULL) 
%     IMAGEPROC is the processed fluorescence image, IMAGEHULL is its binary 
%     convex hull.

BWimage = double(im2bw(imageproc));
imagehull = ml_imgconvhull(BWimage);

% Ahull = area of the convex hull.
Ahull = sum(sum(imagehull));
Acell = sum(sum(mask));
hullfract = Ahull/Acell;

% 'Shape factor' of the convex hull.
%    Phull = approximation to the hull perimeter.
Phull = sum(sum(bwperim(imagehull)));
hullshape = (Phull^2)/(4*pi*Ahull);

names = {'convex_hull:fraction_of_overlap' 'convex_hull:shape_factor'} ;
values = [hullfract hullshape];
